@@ -1,3 +1,30 @@
+tts_language_codes = function() {
+  df = data.frame(
+  language_code = c("ar-XA", "ar-EG", "ar-SA", "bg-BG", "ca-ES", "cs-CZ",
+           "da-DK", "de-AT", "de-CH", "de-DE", "el-GR", "en-AU", "en-CA",
+           "en-GB", "en-IE", "en-IN", "en-US", "es-ES", "es-MX", "fi-FI",
+           "fr-CA", "fr-CH", "fr-FR", "he-IL", "hi-IN", "hr-HR", "hu-HU",
+           "id-ID", "it-IT", "ja-JP", "ko-KR", "ms-MY", "nb-NO", "nl-NL",
+           "pl-PL", "pt-BR", "pt-PT", "ro-RO", "ru-RU", "sk-SK", "sl-SI",
+           "sv-SE", "ta-IN", "te-IN", "th-TH", "tr-TR", "vi-VN", "zh-CN",
+           "zh-HK", "zh-TW", "fil-PH", "uk-UA"),
+  language = c("Arabic", "Arabic (Egypt)", "Arabic (Saudi Arabia)",
+               "Bulgarian", "Catalan (Spain)", "Czech", "Danish", "German (Austria)",
+               "German (Switzerland)", "German (Germany)", "Greek", "English (Australia)",
+               "English (Canada)", "English (UK)", "English (Ireland)", "English (India)",
+               "English (US)", "Spanish (Spain)", "Spanish (Mexico)", "Finnish",
+               "French (Canada)", "French (Switzerland)", "French (France)",
+               "Hebrew (Israel)", "Hindi (India)", "Croatian", "Hungarian",
+               "Indonesian", "Italian", "Japanese", "Korean", "Malay", "Norwegian",
+               "Dutch", "Polish", "Portuguese (Brazil)", "Portuguese (Portugal)",
+               "Romanian", "Russian", "Slovak", "Slovenian", "Swedish", "Tamil (India)",
+               "Telugu (India)", "Thai", "Turkish", "Vietnamese", "Chinese (Mainland)",
+               "Chinese (Hong Kong)", "Chinese (Taiwan)",
+               "Filipino (Philippines)", "Ukrainian (Ukraine)"),
+  stringsAsFactors = FALSE)
+  df
+}
+
 #' Text to Speech Voices
 #'
 
@@ -15,24 +42,28 @@
 #' if (tts_google_auth()) {
 #' tts_voices(service = "google")
 #' }
+#' if (requireNamespace("aws.polly", quietly = TRUE)) {
 #' if (tts_amazon_auth()) {
 #' tts_voices(service = "amazon")
 #' }
+#' }
 tts_voices = function(
-  service = c("amazon", "google", "microsoft")
+  service = c("amazon", "google", "microsoft"),
+  ...
 ) {
   service = match.arg(service)
   res = switch(service,
-         amazon = tts_amazon_voices(),
-         google = tts_google_voices(),
-         microsoft = tts_microsoft_voices()
+         amazon = tts_amazon_voices(...),
+         google = tts_google_voices(...),
+         microsoft = tts_microsoft_voices(...)
   )
   res
 }
 
 #' @rdname tts_voices
 #' @export
-tts_amazon_voices = function() {
+tts_amazon_voices = function(...) {
+  tts_amazon_auth(...)
   if (utils::packageVersion("aws.polly") <= package_version("0.1.4")) {
     # as per https://docs.aws.amazon.com/polly/latest/dg/SupportedLanguage.html
 
@@ -67,7 +98,8 @@ tts_amazon_voices = function() {
 
 #' @rdname tts_voices
 #' @export
-tts_microsoft_voices = function() {
+tts_microsoft_voices = function(...) {
+  # tts_microsoft_auth(...)
   res = mscstts::ms_locale_df()
   cn = colnames(res)
   cn[ cn == "Gender" ] = "gender"
@@ -83,7 +115,8 @@ tts_microsoft_voices = function() {
 
 #' @rdname tts_voices
 #' @export
-tts_google_voices = function() {
+tts_google_voices = function(...) {
+  tts_google_auth(...)
   res = googleLanguageR::gl_talk_languages()
   cn = colnames(res)
   cn[ cn == "ssmlGender" ] = "gender"
@@ -92,7 +125,8 @@ tts_google_voices = function() {
   cn[ cn == "language" ] = "language"
   colnames(res) = cn
   if (!("language" %in% cn)) {
-    df = tts_microsoft_voices()
+    # df = tts_microsoft_voices()
+    df = tts_language_codes()
     df = df[, c("language_code", "language")]
     res = merge(res, df, all.x = TRUE, by = "language_code")
   }
